<?php

	add_theme_support('post-thumbnails');
	add_theme_support('automatic-feed-links');
	
	
	
	/* ==OTHER FUNCTION === */
	
	function ddTimthumb($img = NULL, $width = NULL, $height = NULL) {
		
		//// IF AN imAGE HAS BEEN PROVIDED
		if($img != NULL) {
		
			$image = vt_resize('', $img, $width, $height, true );
			
			//// IF ITS NOT AN ERROR
			if(is_array($image)) { return $image['url']; } else { return ''; }
		
		} else { return ''; }
		
	}
	
	function getFeaturedImage($post_id = NULL) {
		
		if($post_id != NULL) {
			
			$image = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'single-post-thumbnail' );
			return $image;
			
		}
		
	}
	
	function randomString($valid_chars, $length) {
		
		$random_string = "";
	
		$num_valid_chars = strlen($valid_chars);
	
		for ($i = 0; $i < $length; $i++) {
			
			$random_pick = mt_rand(1, $num_valid_chars);
	
			$random_char = $valid_chars[$random_pick-1];
			
			$random_string .= $random_char;
		}
	
		return $random_string;
	}
	
	function getProportionalHeight($original_width, $original_height, $new_width) {
		
		if($new_width) {
			
			$temp = $original_width / $new_width;
			return round($original_height / $temp);
			
		}
		
	}
	
	function format_price($price) {
		
		//// IF IS NUMERIC
		if(is_numeric($price)) {
		
			/// ADDS OUR SIGN BEFORE AND AFTER
			return ddp('price_sign_before').number_format($price).ddp('price_sign_after');
			
		} else { return $price; }
		
	}
	
	function format_property_price($price, $post_id = null) {
		
		//// IF IS NUMERIC
		if(is_numeric($price)) {
		
			//// IF POST IS RENTAL
			if($post_id != null) {
				
				if(get_post_meta($post_id, 'property_lease', true) == 'rental') { return format_price($price).' '.ddp('price_per_week'); }
				else { return format_price($price); }
				
			} else { return format_price($price); }
			
		} else { return $price; }
		
	}


	//////////////////////////////////////////////
	// INSERTS THE NECESSARY SCRIPTS IN OUR WP_HEAD
	// INSERTS CSS AS WELL
	//////////////////////////////////////////////
	
	add_action('wp_enqueue_scripts', 'theme_styles');
	
	function theme_styles() {
		
		//// MAIN STYLE.CSS
		wp_register_style('main',  get_stylesheet_uri(), array(), '20130402', 'all');
		
		//// RESPONSIVE
		wp_register_style('responsive',  get_template_directory_uri().'/css/responsive.css', array(), '20130402', 'all');
		
		//// COLOR
		wp_register_style('theme_color',  get_template_directory_uri().'/css/'.strtolower(ddp('theme_color')).'.css', array(), '20130402', 'all');
		
		//// COLOR
		wp_register_style('touchscroll',  get_template_directory_uri().'/css/touchscroll.css', array(), '20130402', 'all');
		
		//// LET'S ENQUEUE IT
		wp_enqueue_style('main');
		wp_enqueue_style('responsive');
		wp_enqueue_style('theme_color');
		
	}
	
	//// REGISTERS OUR SCRIPTS
	add_action('init', 'ultrasharp_register_scripts');
	
	$wp_scripts = new WP_Scripts();
	function ultrasharp_register_scripts() {
		
		//scripts js
		wp_register_script( 'fiveScripts', get_template_directory_uri().'/js/scripts.js');
		wp_register_script( 'clusterer', get_template_directory_uri().'/js/markerclusterer.js');
		
	}
	
	//// ENQUEUES OUR SCRIPTS
	add_action('wp_enqueue_scripts', 'ultrasharp_enqueue_scripts');
	
	function ultrasharp_enqueue_scripts() {
		
		//// IF SIGN UP IS ENABLED
		if(ddp('public_submissions') == 'on') {
			
			wp_localize_script('fiveScripts', 'agent', array(
			
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'agent_login_nonce' => wp_create_nonce('agent-login-nonce'),
				'agent_register_nonce' => wp_create_nonce('agent-register-nonce'),
				'package_sign_up_nonce' => wp_create_nonce('package-sign-up-nonce')
				
			));
			
		}
		
		//enqueues our scripts. let's enqueue jquery first to just make sure its loaded first in any case
		wp_enqueue_script('jquery');
		wp_enqueue_script('fiveScripts');
		wp_enqueue_script('clusterer');
		wp_enqueue_script('comment-reply');
		
	}
	
	//// GETS TAXONOMY CUSTOM FIELD
	function getTermCustomField($term_id, $custom_field) {
		
		$term_meta = get_option('taxonomy_'.$term_id);
		return $term_meta[$custom_field];
		
	}
	
	//// GETS THE PAGE OR SINGLE HEADER BG
	function get_page_header_bg($post_id) {
		
		//// IF TAXONOMY
		if(is_tax('suburbs')) { $term = get_term_by('name', single_cat_title('', false), 'suburbs'); if(getTermCustomField($term->term_id, 'header_bg') != '') { return getTermCustomField($term->term_id, 'header_bg'); } }
		
		if(is_category()) { $cat = get_term_by('name', single_cat_title('', false), 'category'); if(getTermCustomField($cat->term_id, 'header_bg') != '') { return getTermCustomField($cat->term_id, 'header_bg'); } else { $header_bg = ddp('header_bg'); return $header_bg; } }
		
		if(!is_tax('suburbs')) { $header_bg = get_post_meta($post_id, 'header_bg', true); }
		
		/// IF EMPTY GET DEFAULT
		if($header_bg == '') { $header_bg = ddp('header_bg'); }
		
		return $header_bg;
		
	}
	
	//// ADDS ANALYTICS TO OUR FOOTER
	add_action('wp_footer', 'footer_analytics');
	
	function footer_analytics() {
            
            //// GOOGLE ANALYTICS
            if(ddp('google_analytics') != '') { echo ddp('google_analytics'); }
		
	}

	
	function select_lang() {
	
		// Retrieve the directory for the localization files
		$lang_dir = get_template_directory().'/lang';
		 
		// Set the theme's text domain using the unique identifier from above
		load_theme_textdomain('btoa', $lang_dir);
	 
	}
	add_action('after_setup_theme', 'select_lang');
	
	if ( ! isset( $content_width ) ) $content_width = 1000;
	
	
	
	
	
	//// BETTER SPRINTF
	function sprintf2($str='', $vars=array(), $char='%')
	{
		if (!$str) return '';
		if (count($vars) > 0)
		{
			foreach ($vars as $k => $v)
			{
				$str = str_replace($char . $k, $v, $str);
			}
		}
	
		return $str;
	}

?>